<?php

namespace Teknisa\EST\Modules\Relatorios\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\EST\Modules\Relatorios\Services\Est31700EtiquetadeProdutoService;

class Est31700EtiquetadeProdutoController extends \Teknisa\EST\Controllers\TeknisaCrud{
    
    protected $dataSourceName = "";
    
    public function __construct($crudService, $parameterBag,$environment, ReportService $reportService, Est31700EtiquetadeProdutoService $est31700EtiquetadeProdutoService) {
        parent::__construct($crudService,$parameterBag);
        $this->environment   = $environment;
        $this->reportService = $reportService;
        $this->Est31700EtiquetadeProdutoService = $est31700EtiquetadeProdutoService;
    }
    
    public function generateReport(DTO\Request\Row $request, DTO\Response $response){
        $rows = $request->getRow();
        $parameterRow = "";
        //Verifica se o relatório é "Nº Ordem de Produção"
        foreach($rows as $row){
            if(!empty($row["NRORDPROD"])){
                $opCheck = true;
            }else{
                $opCheck = false;
            }
        }
        
        // Monta array parâmetros
        if($opCheck){
            $reportName = 'EST31700ordProd';
            $filial     = $rows[0]["CDFILIMOVI"];
            $nrordprod = $rows[0]["NUMERO"];
            $nrsubordprod = $rows[0]["NRSUBORDPROD"];
            
            $parameterRow = array("CDFILIAL"   => $filial,
                                  "NRORDPROD"   => $nrordprod,
                                  "NRSUBORDPROD" => $nrsubordprod);
        }else{
            $reportName = 'EST31700';
            $filial     = $rows[0]["CDFILIMOVI"];
            $lancamento = $rows[0]["NRLANCAMENTO"];
            $idtplancto = $rows[0]["IDTPLANCTO"];
            
            $parameterRow = array("CDFILIAL"   => $filial,
                                  "NRLANCTO"   => $lancamento,
                                  "IDTPLANCTO" => $idtplancto);
        }
        
        $itens = '';
            
        foreach($rows as $row){
            $itens .= '_'.$row["SEQUENCIA"];
        };
        
        $itens.='_';
        $parameterRow["NRSEQITEM"] = $itens;
        
       $nrorg = $this->environment->getNrOrgTrab(); 
       $parameterRow['NRORG'] = $nrorg;
       $parametersRow['__format'] = 'PDF';
       
       $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parameterRow);
       $birtLink = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow, true);
      
       $response->addMessage(new DTO\Response\Message($birtURL));
       $response->addMessage(new DTO\Response\Message($birtLink)); 
    }
    
    
    public function getProducts(Filter $request, Response $response){
        try{
            
            $conditions = $request->getFilterCriteria()->getConditions();
            
            foreach ($conditions as $condition) {
                if(is_string($condition["columnName"])) {
                    if($condition["columnName"]=="CDFILIAL"||$condition["columnName"]=="NRLANCTONF"||
                       $condition["columnName"]=="NRLANCESTQ"||$condition["columnName"]=="NRORDPROD"||
                       $condition["columnName"]=="NRSUBORDPROD"){
                       
                        $cleanConditions[] = $condition;
                        
                        if($condition["columnName"]=="NRLANCTONF"||$condition["columnName"]=="NRLANCESTQ"||
                           $condition["columnName"]=="NRORDPROD"){
                            
                            $field = array("name" => $condition["columnName"],"value" => $condition["value"]);
                        }
                    }else{
                        $row[$condition["columnName"]] = $condition["value"];
                    };
                }
            }
            if(empty($row)) $row="";
            
            $this->dataSourceName = $this->Est31700EtiquetadeProdutoService->checkDataSource($field,$row);

            $newFilterCriteria = new FilterCriteria($this->dataSourceName, $cleanConditions);
            $filter = new DTO\Request\Filter($newFilterCriteria, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
            parent::find($filter, $response);
            
            $rows = $response->getDataSets()[0]->getRows();
            $dataSet = new DataSet('get_data_products', $response->getDataSets()[0]->getRows());
            $response->setDataSets(array($dataSet));
            
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
