<?php
namespace Fiscal\Logic\NotaFiscal;


use \Fiscal\Entities\Notafiscal;
use \Geral\Util\Ambiente;
use \Geral\Entities\Itemproduto;
use \Financeiro\Entities\Rattpctp;
use \Fiscal\Entities\Rateionf;

/**
 * Created by JetBrains PhpStorm.
 * User: paulopereira
 * Date: 24/10/12
 * Time: 10:14
 * To change this template use File | Settings | File Templates.
 */
class RateioNotaFiscal
{

    /**@var $notaFiscal Notafiscal*/
    private $notaFiscal;
    /** @var $itensNota array*/
    private $itensNota;
    /** @var $itensNotaRateados array*/
    private $itensNotaRateados;


    /**
     *
     * @param \Fiscal\Entities\Notafiscal $notaFiscal
     */
    public function __construct(Notafiscal $notaFiscal)
    {
        $this->notaFiscal = $notaFiscal;
        $this->itensNota  = Itemproduto::findByCdfilialAndNrlanctonfAndNrorg (
            $this->notaFiscal->getFilial()->getCdfilial(),
            $this->notaFiscal->getNrlanctonf(),
            \Geral\Util\Ambiente::getNrorg()
        );
        $this->itensNotaRateados = array();
    }

    /**
     * Retorna o array com os itens rateados.
     *
     * @return array
     */
    public function geraRateioAnterior()
    {
       /**@var $itemNota Itemproduto*/
       foreach ($this->itensNota as $itemNota) {
           $this->geraListaRateio($itemNota);
       }

       return $this->getItensNotaRateados();
   }

    /**
     * Itera a lista de registros de rateio, a fim de incrementar a lista de rateio de produtos.
     *
     * @param \Geral\Entities\Itemproduto $itemNota
     */
    protected function geraListaRateio(Itemproduto $itemNota)
    {
        $rateioNF = Rateionf::findByCdfilialAndNrlanctonfAndNrseqitprodAndNrorg (
            $this->notaFiscal->getFilial()->getCdfilial(),
            $this->notaFiscal->getNrlanctonf(),
            $itemNota->getNrseqitprod(),
            Ambiente::getNrorg()
        );

        // echo "\n".$this->notaFiscal->getFilial()->getCdfilial();
        // echo "\n".$this->notaFiscal->getNrlanctonf();
        // echo "\n".$itemNota->getNrseqitprod();
        // echo "\n".Ambiente::getNrorg();

        /**@var $itemRateio Rateionf */
        foreach ($rateioNF as $itemRateio) {
            $this->incrementaListaItensRateados($itemNota, $itemRateio);
        }
    }

    /**
     * Adiciona ao array de "itensNotaRateados" um registro de rateio.
     *
     * @param \Geral\Entities\Itemproduto $itemNota
     * @param \Fiscal\Entities\Rateionf $itemRateio
     */
    protected function incrementaListaItensRateados(Itemproduto $itemNota, Rateionf $itemRateio)
    {
        $this->itensNotaRateados[] = array (
            "CDFILIAL"    => $itemRateio->getCdfilial(),
            "NRLANCTONF"  => $itemRateio->getNrlanctonf(),
            "NRSEQITPROD" => $itemRateio->getNrseqitprod(),
            "CDFILICCUST" => $itemRateio->getFiliccust(),
            "CDCENTCUSNF" => $itemRateio->getCentcusnf(),
            "VRRATENF"    => $itemRateio->getVrratenf(),
            "VRPERC"      => ($itemRateio->getVrperrat() > 0)
                               ? $itemRateio->getVrperrat()
                               : (($itemRateio->getVrratenf() * 100) / $itemNota->getVrcontitem()),
        );
    }

    /**
     * @return array
     */
    public function getItensNotaRateados()
    {
        return $this->itensNotaRateados;
    }


    /**
     * Remove o registro de rateio.
     *
     * @param null $cdfilial
     * @param null $nrlanctonf
     */
    public function excluirRateio($cdfilial = null, $nrlanctonf = null)
    {
        // Caso algum dos parametros nao for informado, ambos adotarao os valores da nota fiscal
        // da instancia.
        if (($cdfilial && $nrlanctonf) === false) {
            $cdfilial   = $this->notaFiscal->getFilial()->getCdfilial();
            $nrlanctonf = $this->notaFiscal->getNrlanctonf();
        }

        $rateios = Rateionf::findByCdfilialAndNrlanctonfAndNrorg($cdfilial, $nrlanctonf, Ambiente::getNrorg());
       /** @var $rateio Rateionf */
        foreach($rateios as $rateio){
            $rateio->delete();
        }
        \Setforms2\Shared\Registry::getEntityManager()->flush();
    }

    public function geraRateioContabil()
    {
        if ($this->notaFiscal->getEntrsaidop()->getIdentrsaidop() === \Geral\Entities\Tipooperac::OPERACAO_ENTRADA) {
            $this->processaRateioDeEntrada();
        } else {
            $this->processaRateioDeSaida();
        }

    }

    protected function processaRateioDeEntrada()
    {
        $tipoOperacao = $this->notaFiscal->getEntrsaidop()->getIdconsctbrat();
        $tipoOperacao = ($tipoOperacao) ? $tipoOperacao : \Geral\Entities\Tipooperac::IDCONSCTBRAT_NAO;
        if ($tipoOperacao === \Geral\Entities\Tipooperac::IDCONSCTBRAT_SIM) {
            $this->rateioEntradaConsideraTipoConta();
        } else {
            $this->rateioEntradaNaoConsideraTipoConta();
        }
    }

    protected function processaRateioDeSaida()
    {
        $tipoOperacao = $this->notaFiscal->getEntrsaidop()->getIdconsctbrat();
        $tipoOperacao = ($tipoOperacao) ? $tipoOperacao : \Geral\Entities\Tipooperac::IDCONSCTBRAT_NAO;
        if ($tipoOperacao === \Geral\Entities\Tipooperac::IDCONSCTBRAT_SIM) {
            $this->rateioSaidaConsideraTipoConta();
        } else {
            $this->rateioSaidaNaoConsideraTipoConta();
        }
    }

    protected function rateioEntradaConsideraTipoConta()
    {
        $tipoContaPagar = $this->getTipoContaPagar();
        $itensRateio    = Rattpctp::findByCdtpctpagarAndNrorg ($tipoContaPagar, Ambiente::getNrorg());
        $itensNota      = $this->itensNota;

        foreach ($itensNota as $itemNota) {
            foreach ($itensRateio as $itemRateio) {
                $this->insereRateio($itemNota, $itemRateio);
            }
        }

    }

    /**
     * Instancia um objeto de Rattpctp e insere os dados devidos.
     *
     * @param \Geral\Entities\Itemproduto $itemNota
     * @param \Financeiro\Entities\Rattpctp $itemRateio
     */
    protected function insereRateio(Itemproduto $itemNota, Rattpctp $itemRateio)
    {
        $rateionf = new Rateionf();
        $rateionf->setDtinclusao(new \DateTime());
        $rateionf->setDtultatu(new \DateTime());
        $rateionf->setNrorginclusao(Ambiente::getNrorg());
        $rateionf->setCdoperinclusao(Ambiente::getCdOperador());
        $rateionf->setNrorgultatu(Ambiente::getNrorg());
        $rateionf->setCdoperultatu(Ambiente::getCdOperador());
        $rateionf->setSeqitprod(Itemproduto::getObject(array(
            "nrorg"       => Ambiente::getNrorg(),
            "nrseqitprod" => $itemNota->getNrseqitprod(),
            "nrlanctonf"  => $this->notaFiscal->getNrlanctonf(),
            "cdfilial"    => $this->notaFiscal->getFilial()->getCdfilial(),
        )));
        $rateionf->setFiliccust($this->notaFiscal->getFilirece());
        $rateionf->setCentcusnf($itemRateio->getCentcust());
        $rateionf->setVrratenf($itemNota->getVrcontitem() * ($itemRateio->getVrperattpctp() / 100));
        $rateionf->setVrperrat($itemRateio->getVrperattpctp());
        $rateionf->persist();
    }

    /**
     * @return string
     */
    protected function getTipoContaPagar()
    {
        /** @var $repositorioContapagar \Fiscal\Repositories\Contapagar*/
        $repositorioContapagar = \Fiscal\Entities\Contapagar::getRepository();
        $contaPagar =  $repositorioContapagar->getTipoContaPagar (
            $this->notaFiscal->getFilial()->getCdfilial(),
            $this->notaFiscal->getNrlanctonf(),
            Ambiente::getNrorg()
        );

        if ((bool)$contaPagar === false) {
            /** @var $repositorioItemproduto \Geral\Repositories\Itemproduto */
            $repositorioItemproduto = \Geral\Entities\Itemproduto::getRepository();
            $contaPagar = $repositorioItemproduto->getTipoContaPagar(
                $this->notaFiscal->getFilial()->getCdfilial(),
                $this->notaFiscal->getNrlanctonf(),
                Ambiente::getNrorg()
            );
        }

        return $contaPagar;
    }

    protected function rateioEntradaNaoConsideraTipoConta()
    {
        /** @var $repositorioRateionf \Fiscal\Repositories\Rateionf */
        $repositorioRateionf = \Fiscal\Entities\Rateionf::getRepository();
        $repositorioRateionf->insereRateioEntrada (
            $this->notaFiscal->getFilial()->getCdfilial(),
            $this->notaFiscal->getNrlanctonf(),
            $this->notaFiscal->getFilirece()->getCdfilial()
        );
    }

    protected function rateioSaidaConsideraTipoConta()
    {
        $tipoContaReceber = $this->getTipoContaReceber();
        $itensNota        = $this->itensNota;
        $itensRateio      = Rattpctp::findByCdtpctrecebAndNrorg($tipoContaReceber, Ambiente::getNrorg());

        foreach ($itensNota as $itemNota) {
            foreach ($itensRateio as $itemRateio) {
                $this->insereRateio($itemNota, $itemRateio);
            }
        }

    }

    protected function rateioSaidaNaoConsideraTipoConta()
    {
        /** @var $repositorioRateionf \Fiscal\Repositories\Rateionf */
        $repositorioRateionf = \Fiscal\Entities\Rateionf::getRepository();
        $repositorioRateionf->insereRateioSaida (
            $this->notaFiscal->getFilial()->getCdfilial(),
            $this->notaFiscal->getNrlanctonf()
        );
    }

    /**
     * @return string
     */
    protected function getTipoContaReceber()
    {
        /** @var $repositorioItemproduto \Geral\Repositories\Itemproduto */
        $repositorioItemproduto = \Geral\Entities\Itemproduto::getRepository();
        $contaReceber = $repositorioItemproduto->getTipoContaReceber (
            $this->notaFiscal->getFilial()->getCdfilial(),
            $this->notaFiscal->getNrlanctonf()
        );

        return $contaReceber;
    }

}
